==> haskell-yesod-core-1.6.27.1-102.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-I5ZZPFaKOIQvGLDwT7kXh
key:                  yesod-core-1.6.27.1-I5ZZPFaKOIQvGLDwT7kXh
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  75e4e6c43ebd8bb5954322165ed26d9b
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-I5ZZPFaKOIQvGLDwT7kXh
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-aeson-2.1.0.0-4vY3J0brPwKGduZzr9qLSE
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj
    blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-61fbRqBqQFu1RDoO1WbwIS
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-4mR0wENhtiT2BdGv1Hn8yK mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    shakespeare-2.1.7-ApGKvgcgjcbHs7XYUEyo0A template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
    wai-extra-3.1.18-KQeg0gFAVbX8uVGY4yZdcS
    wai-logger-2.5.0-DJcZLrYZUmgA3l0XNoCO69
    warp-3.4.0-EqimZsrxjZl395Jtpn7CJI
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.27.1-103-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-9M5c258biFQ3gXF13H4oaO
key:                  yesod-core-1.6.27.1-9M5c258biFQ3gXF13H4oaO
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  432e5ccc720cdca31536276a08e09e71
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-9M5c258biFQ3gXF13H4oaO
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-aeson-2.1.0.0-4vY3J0brPwKGduZzr9qLSE
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj
    blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-61fbRqBqQFu1RDoO1WbwIS
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    shakespeare-2.1.7-ApGKvgcgjcbHs7XYUEyo0A template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
    wai-extra-3.1.18-1cKRYsHDvT8fkYumb3esL
    wai-logger-2.5.0-DJcZLrYZUmgA3l0XNoCO69
    warp-3.4.0-HpC7vpiyF2eriPYOziTRJ word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
